/***************************************************************************

  gb_magic.h

  Magic numbers

  Copyright (c) 2000-2007 Benoit Minisini <gambas@freesurf.fr>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __GB_MAGIC_H
#define __GB_MAGIC_H

#define OUTPUT_MAGIC      0x9A177BA5
#define OUTPUT_ENDIAN     0x12345678

#define ARCH_MAGIC        0xA7C4117E
#define ARCH_VERSION      2

#define PROJECT_MAGIC     "# Gambas Project File"

#endif
